@@ -20,7 +20,7 @@ use strict;
 
 package Mac::AppleEvents;
 use vars '$VERSION';
-$VERSION = 1.23;
+$VERSION = 1.24;
 
 =head2 Constants: AppleEvent Descriptor Types
 
@@ -477,6 +477,8 @@ sub kNoTimeOut					  () {		   -2; }
 
 Options for C<AEResumeTheCurrentEvent()>.
 
+=back
+
 =cut
 sub kAENoDispatch				  () {			0; }
 sub kAEUseStandardDispatch		  () { 0xFFFFFFFF; }
@@ -564,9 +566,6 @@ sub kAEEndsWith                   () {     'ends'; }
 sub kAEContains                   () {     'cont'; }
 
 }
-=back
-
-=cut
 
 BEGIN {
 	use Exporter   ();
@@ -896,6 +895,8 @@ AEDesc is a Perl package that encapsulates an AppleEvent Descriptor.
 It uses the OO methods of Perl5 to make building and parsing data structures
 easier.
 
+=over 4
+
 =item new TYPE, HANDLE
 
 =item new TYPE, DATA
@@ -993,6 +994,8 @@ AEKeyDesc is a Perl package that encapsulates an AppleEvent keyword.
 It uses the OO methods of Perl5 to make building and parsing data structures
 easier.
 
+=over 4
+
 =item new KEY, TYPE, HANDLE
 
 =item new KEY, TYPE, DATA
@@ -1063,9 +1066,9 @@ sub new {
 
 =head1 AUTHOR
 
-Matthias Ulrich Neeracher neeracher@mac.com "Programs"
-
-Bob Dalgleish bob.dalgleish@sasknet.sk.ca "Documentation"
+Written by Matthias Ulrich Neeracher E<lt>neeracher@mac.comE<gt>,
+documentation by Bob Dalgleish E<lt>bob.dalgleish@sasknet.sk.caE<gt>.
+Currently maintained by Chris Nandor E<lt>pudge@pobox.comE<gt>.
 
 =cut
 1;
