@@ -31,6 +31,13 @@ a familiarity with Carbon is assumed in the POD), see apple.com.
 
 	http://developer.apple.com/techpubs/macosx/Carbon/
 
+The documentation is also located on your system, if you have the Developer
+Tools installed, at /Developer/Documentation/Carbon/.
+
+Also of significant use are the related header files on your system.  Use
+the `locate` command to find them.  They contain current documentation and
+notes for the API.
+
 The modules were written for Mac OS originally, and are in part being
 ported to Carbon.  You may also be interested in the original documentation.
 
@@ -130,12 +137,11 @@ of the issues, including bugs and possibilities for bugs, involved.
 
 =item *
 
-AEGetDescData is screwing up on returning data of type TEXT with two or
-three characters, in AppleEvents.xs for AEDesc->data().  Freaky.
+When creating FSSpecs, the file must exist.  This is Bad.
 
 =item *
 
-When creating FSSpecs, the file must exist.  This is Bad.
+[GS]etFileInfo fails on UFS.
 
 =item *
 
@@ -144,18 +150,6 @@ Processes fields).  Generate list of all unsupported functions.
 
 =item *
 
-Deal with xsubpp issues (F<README>).
-
-=item *
-
-Related to xsubpp issues, embedded POD in .xs should somehow be moved
-to .pm files (perhaps the new preprocessor could automatically dump
-the POD into the corresponding .pm file).  This currently causes an
-error during the build, and results in man pages not being properly
-created, with all the documentation.
-
-=item *
-
 Test suite needs a lot of work. There are surely bugs to be uncovered
 in a test suite.  All modules have been tested to some degree, but more
 exhaustive testing needs to happen.
@@ -182,11 +176,12 @@ then the tied %Application hash should be implemented differently.
 
 =item *
 
-In MacPerl package, perhaps support Ask/Answer/Pick via DoAppleScript.
+Can we support XCMDs etc. via XL?  Do we want to?
 
 =item *
 
-Can we support XCMDs etc. via XL?  Do we want to?
+Find a way to open resources stored in data files.  Technically not a bug,
+but darnit, it's a pain in the rear.
 
 =back
 
@@ -197,12 +192,14 @@ Can we support XCMDs etc. via XL?  Do we want to?
 See each individual module for more information on use.  See F<README>
 for more information about modules not included here.
 
+	Mac::AppleEvents	appleevents
 	Mac::Components		components
 	Mac::Files		files
 	Mac::Gestalt		gestalt
 	Mac::Memory		memory
 	Mac::MoreFiles		morefiles
 	Mac::Notification	notification
+	Mac::OSA		osa	
 	Mac::Processes		processes
 	Mac::Resources		resources
 	Mac::Sound		sound
@@ -218,18 +215,20 @@ use strict;
 use base 'Exporter';
 use vars qw(@EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 # we are just a frontend, so loop over the modules, and
 # suck up everything in @EXPORT
 BEGIN {
 	my @modules = qw(
+		AppleEvents
 		Components
 		Files
 		Gestalt
 		Memory
 		MoreFiles
 		Notification
+		OSA
 		Processes
 		Resources
 		Sound
@@ -269,8 +268,14 @@ Nandor E<lt>pudge@pobox.comE<gt>.
 =head1 THANKS
 
 Michael Blakeley E<lt>mike@blakeley.comE<gt>,
+Emmanuel. M. Decarie E<lt>emm@scriptdigital.comE<gt>,
+brian d foy E<lt>comdog@panix.comE<gt>,
+David Hand E<lt>davidhand@davidhand.comE<gt>,
 Gero Herrmann E<lt>herr@ils.uec.ac.jpE<gt>,
-Dan Sugalksi E<lt>dan@sidhe.orgE<gt>.
+Paul McCann E<lt>pmccann@maths.adelaide.edu.auE<gt>,
+Dan Sugalksi E<lt>dan@sidhe.orgE<gt>,
+Ken Williams E<lt>ken@mathforum.orgE<gt>,
+Steve Zellers.
 
 =head1 SEE ALSO
 
